@@ -1,6 +1,6 @@
 // direct-illum.h -- Direct-lighting calculations
 //
-//  Copyright (C) 2010  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2010-2012  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -10,8 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
-#ifndef __DIRECT_ILLUM_H__
-#define __DIRECT_ILLUM_H__
+#ifndef SNOGRAY_DIRECT_ILLUM_H
+#define SNOGRAY_DIRECT_ILLUM_H
 
 #include "color.h"
 #include "bsdf.h"
@@ -38,9 +38,9 @@ public:
 
     // Constructor that allows explicitly setting the number of samples.
     //
-    GlobalState (unsigned num_light_samples);
+    GlobalState (unsigned num_samples);
 
-    unsigned num_light_samples;
+    unsigned num_samples;
   };
 
   DirectIllum (RenderContext &context, const GlobalState &global_state);
@@ -109,4 +109,4 @@ private:
 
 }
 
-#endif // __DIRECT_ILLUM_H__
+#endif // SNOGRAY_DIRECT_ILLUM_H
