@@ -1,6 +1,6 @@
 // excepts.h -- Snogray exceptions
 //
-//  Copyright (C) 2005, 2007  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2005, 2007, 2011  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -10,8 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
-#ifndef __EXCEPTS_H__
-#define __EXCEPTS_H__
+#ifndef SNOGRAY_EXCEPTS_H
+#define SNOGRAY_EXCEPTS_H
 
 #include <stdexcept>
 #include <string>
@@ -32,6 +32,6 @@ struct file_error : public std::runtime_error
 
 }
 
-#endif /* __EXCEPTS_H__ */
+#endif /* SNOGRAY_EXCEPTS_H */
 
 // arch-tag: 0a852d69-b721-4bc6-912c-5cb042fc6357
