@@ -11,10 +11,10 @@
 --
 
 
-module ("snogray", package.seeall)
+module ("snogray.snogray", package.seeall)
 
 
-local raw = require "snograw"
+local raw = require "snogray.snograw"
 
 -- Until recently, Swig-generated Lua modules didn't return the module
 -- table from require (as is recommended), but instead stored it into
@@ -1688,11 +1688,12 @@ end
 -- files of the same type.
 --
 local function add_autoload_stub (loader_table, ext, loader_file, loader_name)
+   local loader_dir = require ('snogray.environ').lua_loader_dir
    loader_table[ext]
       = function (...)
 	   print ("* autoloading: "..loader_file)
 
-	   local contents, err = loadfile (loader_file)
+	   local contents, err = loadfile (loader_dir.."/"..loader_file)
 
 	   if contents then
 	      local environ = {}
